# Examples

- Example 1: [eCommerce.ipynb](eCommerce.ipynb) - For the most thorough overview
- Example 2: [housing.py](housing.py) - Used in blog 1
- Example 3: [avocados.ipynb](avocados.ipynb) - Used in blog 2
- Example 4: [housing_different_levels.py](housing_different_levels.py) - Used in blog 3
- Example 5: [LSTM.ipynb](LSTM.ipynb) - Used in blog 5

## See the blog posts:
1. [Intro](https://towardsdatascience.com/introducing-scalecast-a-forecasting-library-pt-1-33b556d9b019)
2. [Forecasting many series automatically](https://towardsdatascience.com/may-the-forecasts-be-with-you-introducing-scalecast-pt-2-692f3f7f0be5)
3. [Forecasting models on different levels](https://towardsdatascience.com/forecast-on-3-levels-introducing-scalecast-pt-3-eb725e0be6c9)
4. [Forecasting with 2nd differences](https://medium.com/codex/forecasting-home-prices-in-your-zip-code-ab9be2c33d0e)
5. [Foreasting with LSTM](https://towardsdatascience.com/exploring-the-lstm-neural-network-model-for-time-series-8b7685aa8cf)